<!DOCTYPE html>
<html>
<head>
    <style>
        body {
            color: #5D6D7E;
            font-family: Arial, Helvetica, sans-serif;
        }
        div#form-container {
            margin-left: auto;
            margin-right: auto;
            padding: 2%;
            width: 40%;
        }
        input {
            width: 100%;
            margin-top: 10px;
            margin-bottom: 10px;
            color: #5D6D7E;
        }
        input[type="text"], input[type="number"] {
            border-radius: 10px;
            height: 25px;
            border: none;
            background: #EAECEE;
            padding: 5px 10px 5px 10px;
        }
        input[type="submit"] {
            background: #ABEBC6;
            border-radius: 10px;
            height: 35px;
            border: none;
            font-weight: bolder;
            font-size: 18px;
            color: #5D6D7E;
            cursor: pointer;
        }
        span {
            color: red;
        }
        h1, h3, h4 {
            text-align: center;
        }
    </style>
    <title>Create/Add Token</title>
</head>
    <body>
        <div id="form-container">
            <h1>Add Token</h1>
            <form method="post" action="/add_token/">
                {% csrf_token %}

                {{ form }}
                <label>Auth Token: </label>
                <input type="text" name="auth_token">
                <input type="submit" value="ADD TOKEN">
            </form>

            {% if submitted %}
                <h3>{{ message }}</h3>
                {% if owner != '' %}
                    <h4>Owner Auth Token: {{ owner }}</h4>
                {% endif %}
            {% endif %}
        </div>
    </body>
</html>
